@@ -10,6 +10,7 @@ import click
 
 import enlighten
 
+from ..configurations.globals import globalConfiguration
 from ..prompters import (CyclePayload, Payload, PayloadCollection, Prompter,
                          SchedulePayload, UserPayload)
 from ..schemas.timetable import TimeTable, TimeTableItem
@@ -32,9 +33,7 @@ class ScheduledTimeTableItem:
                 self.raw.cycleWork, self.raw.cycleIndex))
 
         if isinstance(self.raw.payload, PayloadCollection):
-            for payload in self.raw.payload:
-                if payload is not None:
-                    payloads.withPayload(payload)
+            payloads.withPayloads(self.raw.payload)
         elif isinstance(self.raw.payload, Payload):
             payloads.withPayload(self.raw.payload)
         elif self.raw.payload is not None:
@@ -98,16 +97,19 @@ class Scheduler:
                     now = datetime.now().time()
                     if raw.time <= now:
                         self._logger.info(f"Occurring: {raw}.")
+                        pbar.update(pbar.total - pbar.count)
+                        status.update(f"{self._STR_ATTENTION} {message}")
+
                         click.echo(f"{self._STR_ATTENTION} {message}")
 
-                        result = prompter.prompt(item.buildPayloads())
+                        result = prompter.safePrompt(item.buildPayloads())
                         self._logger.info(f"Prompting result: {result}.")
                         return True
                     else:
                         delta = subtract_time(raw.time, now)
                         count = int(round(delta.total_seconds()))
                         pbar.update((pbar.total - count) - pbar.count)
-                    sleep(1)
+                    sleep(globalConfiguration.timeslice.total_seconds())
 
             return False
 
